@@ -175,11 +175,10 @@ func init() {
 	startCmd.Flags().StringVar(&startCmdArgs.MountType, "mount-type", defaultMountTypeQEMU, "volume driver for the mount ("+mounts+")")
 	startCmd.Flags().BoolVar(&startCmdArgs.MountINotify, "mount-inotify", true, "propagate inotify file events to the VM")
 
-	// ssh agent
+	// ssh
 	startCmd.Flags().BoolVarP(&startCmdArgs.ForwardAgent, "ssh-agent", "s", false, "forward SSH agent to the VM")
-
-	// ssh config generation
 	startCmd.Flags().BoolVar(&startCmdArgs.SSHConfig, "ssh-config", true, "generate SSH config in ~/.ssh/config")
+	startCmd.Flags().IntVar(&startCmdArgs.SSHPort, "ssh-port", 0, "SSH server port")
 
 	// k8s
 	startCmd.Flags().BoolVarP(&startCmdArgs.Kubernetes.Enabled, "kubernetes", "k", false, "start with Kubernetes")
@@ -243,12 +242,6 @@ func setDefaults(cmd *cobra.Command) {
 		startCmdArgs.VMType = defaultVMType
 	}
 
-	// m3 devices cannot use qemu
-	if util.M3() {
-		startCmdArgs.VMType = "vz"
-		cmd.Flag("vm-type").Changed = true
-	}
-
 	if util.MacOS13OrNewer() {
 		// changing to vz implies changing mount type to virtiofs
 		if cmd.Flag("vm-type").Changed && startCmdArgs.VMType == "vz" && !cmd.Flag("mount-type").Changed {
@@ -281,10 +274,6 @@ func setConfigDefaults(conf *config.Config) {
 	if conf.VMType == "" {
 		conf.VMType = defaultVMType
 	}
-	// m3 devices cannot use qemu
-	if util.M3() {
-		conf.VMType = "vz"
-	}
 
 	if conf.MountType == "" {
 		conf.MountType = defaultMountTypeQEMU
@@ -388,6 +377,9 @@ func prepareConfig(cmd *cobra.Command) {
 	if !cmd.Flag("ssh-config").Changed {
 		startCmdArgs.SSHConfig = current.SSHConfig
 	}
+	if !cmd.Flag("ssh-port").Changed {
+		startCmdArgs.SSHPort = current.SSHPort
+	}
 	if !cmd.Flag("dns").Changed {
 		startCmdArgs.Network.DNSResolvers = current.Network.DNSResolvers
 	}
