@@ -14,7 +14,6 @@ import (
 	"github.com/abiosoft/colima/daemon"
 	"github.com/abiosoft/colima/environment"
 	"github.com/abiosoft/colima/environment/container/containerd"
-	"github.com/abiosoft/colima/environment/container/docker"
 	"github.com/abiosoft/colima/environment/vm/lima/limautil"
 	"github.com/abiosoft/colima/util"
 	"github.com/abiosoft/colima/util/osutil"
@@ -114,14 +113,6 @@ func (l *limaVM) Start(ctx context.Context, conf config.Config) error {
 		return nil
 	})
 
-	// restart needed for docker user
-	if conf.Runtime == docker.Name {
-		a.Add(func() error {
-			ctx := context.WithValue(ctx, cli.CtxKeyQuiet, true)
-			return l.Restart(ctx)
-		})
-	}
-
 	l.addPostStartActions(a, conf)
 
 	return a.Exec()
